@CHARSET "UTF-8";

/*
 * jQuery UI Multi-Progress Bar 1.1.0
 * http://github.com/j-ulrich/jquery-ui-multiprogressbar
 *
 * Copyright (c) 2012 Jochen Ulrich <jochenulrich@t-online.de>
 * Licensed under the MIT license (MIT-LICENSE.txt).
 */

.ju-multiprogressbar .ui-progressbar-value {
    float: left;
}

.ju-multiprogressbar .ju-multiprogressbar-valuetext {
    margin-top: 0.3em;
    text-align: center;
}